pub struct Session {
pub dir: PathBuf,
pub metadata: SessionMetadata,
pub overlay: OverlayMetadata,
}Fields
dir: PathBufmetadata: SessionMetadataoverlay: OverlayMetadataImplementations
Sourceimpl Session
impl Session
Sourcepub fn create(session_dir: &Path, image_path: &Path) -> Result<Self>
pub fn create(session_dir: &Path, image_path: &Path) -> Result<Self>
Create a new session, computing the SHA-256 of the image and persisting
session.json plus an empty overlay/metadata.json.
Sourcepub fn resume(session_dir: &Path, image_path: &Path) -> Result<Self>
pub fn resume(session_dir: &Path, image_path: &Path) -> Result<Self>
Resume an existing session, verifying the image hash matches.
Sourcepub fn overlay_file_path(&self, id: &str) -> PathBuf
pub fn overlay_file_path(&self, id: &str) -> PathBuf
Return the filesystem path for an overlay file by id.